<?php
/*
Plugin Name: TWD Security Starter Pack
Plugin URI: https://www.tigaman.com/
Description: This plugin enhances security by blocking access to user-related REST API endpoints, disabling PHP file editing, removing the WordPress version from the head, and renaming the login page.
Version: 1.1
Author: tigaman
Author URI: https://www.tigaman.hu/
License: GPL2
*/

// Block access to user-related REST API endpoints
add_filter('rest_endpoints', function ($endpoints) {
    if (is_user_logged_in()) {
        unset($endpoints['/wp/v2/users']);
        unset($endpoints['/wp/v2/users/(?P<id>[\d]+)']);
    }
    return $endpoints;
});

// Disable PHP file editing
define('DISALLOW_FILE_EDIT', true);

// Remove WordPress version from the head
remove_action('wp_head', 'wp_generator');



function twd_security_start_pack_change_login_activate() {
    add_option('twdclpurl', 'root', '', 'yes');
}
register_activation_hook(__FILE__, 'twd_security_start_pack_change_login_activate');

function twd_security_start_pack_change_login_head() {
    $EHL_newurl = get_option('twdclpurl');

    // Check if the user is already logged in
    if (is_user_logged_in()) {
        return;
    }

    if (isset($_GET['action']) && isset($_GET['key'])) {
        return;
    }
    if (isset($_GET['action']) && $_GET['action'] == 'resetpass') {
        return;
    }
    if (isset($_GET['action']) && $_GET['action'] == 'rp') {
        return;
    }
    if (isset($_POST['redirect_newurl']) && $_POST['redirect_newurl'] == $EHL_newurl) {
        return false;
    }
    if (strpos($_SERVER['REQUEST_URI'], 'action=logout') !== false) {
        check_admin_referer('log-out');
        $user = wp_get_current_user();
        wp_logout();
        wp_safe_redirect(home_url(), 302);
        die;
    }
    if (strpos($_SERVER['REQUEST_URI'], $EHL_newurl) === false) {
        wp_safe_redirect(home_url('/404'), 302);
        exit();
    }
    if ((strpos($_SERVER['REQUEST_URI'], $EHL_newurl) === false) &&
        (strpos($_SERVER['REQUEST_URI'], 'wp-login.php') !== false)) {
        wp_safe_redirect(home_url('/404' . $EHL_newurl), 302);
        exit();
    }
}

add_action('login_init', 'twd_security_start_pack_change_login_head', 1);

function twd_security_start_pack_change_login_hidden_field() {
    $EHL_newurl = get_option('twdclpurl', '');
    ?>
    <input type="hidden" name="redirect_newurl" value="<?php esc_attr_e($EHL_newurl) ?>" />
<?php
}
add_action('login_form', 'twd_security_start_pack_change_login_hidden_field');

function twd_security_start_pack_change_login_init() {
    $EHL_newurl = get_option('twdclpurl');
    if (parse_url($_SERVER['REQUEST_URI'], PHP_URL_PATH) == "/$EHL_newurl") {
        wp_safe_redirect(home_url("wp-login.php/$EHL_newurl&redirect=false"));
        exit();
    }
}
add_action('init', 'twd_security_start_pack_change_login_init');

function twd_security_start_pack_change_login_lostpassword() {
    $newurl = get_option('twdclpurl');
    return site_url("wp-login.php/$newurl?action=lostpassword&redirect=false");
}
add_filter('lostpassword_url', 'twd_security_start_pack_change_login_lostpassword', 10, 0);

function twd_security_start_pack_change_login_lostpassword_redirect($lostpassword_redirect) {
    $EHL_newurl = get_option('twdclpurl');
    return 'wp-login.php?checkemail=confirm&redirect=false&' . $EHL_newurl;
}
add_filter('lostpassword_redirect', 'twd_security_start_pack_change_login_lostpassword_redirect', 100, 1);

/* add menue in admin */
add_action('admin_menu', 'twd_security_start_pack_wp_change_login_plugin_menu');

/** Step 1. */
function twd_security_start_pack_wp_change_login_plugin_menu() {
    add_options_page('Change login page Options', 'Change login URL', 'manage_options', 'twd-security-starter-pack-change-login', 'twd_security_start_pack_wp_change_login_plugin_options');
}

/** Step 3. */
function twd_security_start_pack_wp_change_login_plugin_options() {
    if (!current_user_can('manage_options')) {
        wp_die(__('You do not have sufficient permissions to access this page.'));
    }

    if (isset($_POST['newurl'])) {
        $newurl = esc_sql($_POST['newurl']);
        update_option('twdclpurl', $newurl);
    }

    $nonce = wp_create_nonce('twd-security-starter-pack-change-login');
    $newurl = get_option('twdclpurl', '');
    ?>
    <div class="admin_menu">
        <h2>tigaman webdesign - Change login page URL</h2>
        <form action="options-general.php?page=twd-security-starter-pack-change-login&_wpnonce=<?php echo $nonce; ?>" method="POST">
            <div class="twdhlpurl"><label> new login url ending:</label>
                <input type="text" value="<?php esc_attr_e($newurl) ?>" name="newurl" class="regular-text">
            </div>
            <div class="twdhlpurl">Your login url: <b><?php bloginfo('url') ?>/<?php esc_attr_e($newurl) ?></b></div>
            <div class="twdhlpurl"><input type="submit" class="button button-primary" value="Submit"></div>
        </form>

    </div>
<style type="text/css">
.twdhlpurl {padding:10px;
}
.admin_menu {margin:80px 0 0 0}
#wpfooter {display:none;}
#tigamandotcom {
	width: 100%;
	height: 800px;
	overflow-x: hidden;
}
#habar {
	background-color: #d4edda;
	border-color: #c3e6cb;
	color: #155724;
	padding: 1rem;
	margin: 1rem 0;
	position: absolute;
	width: 50%;
	right: 10%;
	
}

.close-button {
	position: absolute;
	top: 10px;
	right: 10px;
	cursor: pointer;
	width: 35px;
	height: 35px;
	background-image: url("data:image/svg+xml;charset=utf8,%3C?xml version='1.0' encoding='UTF-8' standalone='no'?%3E%3C!-- Uploaded to: SVG Repo, www.svgrepo.com, Generator: SVG Repo Mixer Tools --%3E%3Csvg width='800px' height='800px' viewBox='0 -0.5 21 21' version='1.1' xmlns='http://www.w3.org/2000/svg' xmlns:xlink='http://www.w3.org/1999/xlink'%3E%3Ctitle%3Eclose [%231538]%3C/title%3E%3Cdesc%3ECreated with Sketch.%3C/desc%3E%3Cdefs%3E%3C/defs%3E%3Cg id='Page-1' stroke='none' stroke-width='1' fill='none' fill-rule='evenodd'%3E%3Cg id='Dribbble-Light-Preview' transform='translate(-139.000000, -160.000000)' fill='%23000000'%3E%3Cg id='icons' fill='green' transform='translate(56.000000, 160.000000)'%3E%3Cpath d='M85.1,18 L101.9,18 L101.9,2 L85.1,2 L85.1,18 Z M83,20 L104,20 L104,0 L83,0 L83,20 Z M89.7872,11.856 L92.01425,9.735 L89.7872,7.613 L91.2719,6.199 L93.5,8.321 L95.72705,6.199 L97.21175,7.613 L94.9847,9.735 L97.21175,11.856 L95.72705,13.27 L93.5,11.149 L91.2719,13.27 L89.7872,11.856 Z' id='close-[%231538]'%3E%3C/path%3E%3C/g%3E%3C/g%3E%3C/g%3E%3C/svg%3E");
	background-size: cover;
	z-index:5;
}

.close-button:hover {
opacity:.5;
}

p {
  margin: 0;
}

  </style>              
<embed id="tigamandotcom" type="text/html" src="https://www.tigaman.com/tigaman-webdesign-wordpress-plugins/"></embed> 
 </div>
<script type="text/javascript">
function Hide(HideID) 
{
  HideID.style.display = "none"; 
}
</script>      
<?php
}

if (isset($_POST['newurl'])) {
    $newurl = esc_sql($_POST['newurl']);
    update_option('twdclpurl', $newurl);
    echo '<div id="habar"><div class="close-button" onclick="Hide(habar);"></div><p>New URL has been set to: ' . get_bloginfo('url') . '/' . $newurl . '</p></div>';
}

?>
<?php add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'twd_security_start_pack_settings_link');
function twd_security_start_pack_settings_link(array $links)
{
    $url = get_admin_url() . "admin.php?page=twd-security-starter-pack-change-login";
    $settings_link = '<a href="' . $url . '">' . __('Settings', 'akismet') . '</a>';
    $links[] = $settings_link;
    return $links;
}
?>
<?php
function twd_security_start_pack_custom_404_page() {
    if (is_404()) {
        global $wp_query;
        $wp_query->set_404();
        status_header(404);
        $template_dir = get_template_directory();
        $custom_404_file = $template_dir . '/404.php';
        if (!file_exists($custom_404_file)) {
            $plugin_dir = plugin_dir_path(__FILE__);
            $default_404_file = $plugin_dir . '/404.php';
            copy($default_404_file, $custom_404_file);
        }
        include($custom_404_file);
        exit();
    }
}

add_action('template_redirect', 'twd_security_start_pack_custom_404_page');

?>
